summaryrefslogtreecommitdiff
path: root/include/asterisk/channel.h
diff options
context:
space:
mode:
authorRichard Mudgett <rmudgett@digium.com>2012-06-08 20:49:00 +0000
committerRichard Mudgett <rmudgett@digium.com>2012-06-08 20:49:00 +0000
commit8b2412db289b43202ef33053fb4efc4481d99bd4 (patch)
tree2b32104f4cb3176802581a4ceb4d7c58d91d6200 /include/asterisk/channel.h
parent4ca35e090740f3df3450f4ed11abecf68c2546cc (diff)
Tweak ast_channel_softhangup_withcause_locked() to take a typed parameter.
git-svn-id: https://origsvn.digium.com/svn/asterisk/trunk@368712 65c4cc65-6c06-0410-ace0-fbb531ad65f3
Diffstat (limited to 'include/asterisk/channel.h')
-rw-r--r--include/asterisk/channel.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/asterisk/channel.h b/include/asterisk/channel.h
index da3515754..f183fe00e 100644
--- a/include/asterisk/channel.h
+++ b/include/asterisk/channel.h
@@ -1407,11 +1407,11 @@ int ast_check_hangup_locked(struct ast_channel *chan);
/*!
* \brief Lock the given channel, then request softhangup on the channel with the given causecode
* \param obj channel on which to hang up
* \param causecode cause code to use
* \return 0
*/
-int ast_channel_softhangup_withcause_locked(void *obj, int causecode);
+void ast_channel_softhangup_withcause_locked(struct ast_channel *chan, int causecode);
/*!
* \brief Compare a offset with the settings of when to hang a channel up
@@ -1407,11 +1407,11 @@ int ast_check_hangup_locked(struct ast_channel *chan);
/*!
* \brief Lock the given channel, then request softhangup on the channel with the given causecode
- * \param obj channel on which to hang up
- * \param causecode cause code to use
- * \return 0
+ * \param chan channel on which to hang up
+ * \param causecode cause code to use (Zero if don't use cause code)
+ * \return Nothing
*/